dbaccess/source/ui/browser/unodatbr.cxx                                        
              |    2 -
 editeng/source/editeng/impedit3.cxx                                            
              |    2 -
 filter/source/config/cache/cacheitem.hxx                                       
              |    2 -
 filter/source/config/cache/typedetection.hxx                                   
              |    4 +-
 fpicker/source/win32/misc/WinImplHelper.cxx                                    
              |    4 +-
 framework/inc/classes/filtercachedata.hxx                                      
              |    4 +-
 framework/inc/dispatch/closedispatcher.hxx                                     
              |    2 -
 framework/inc/dispatch/interceptionhelper.hxx                                  
              |    2 -
 framework/inc/general.h                                                        
              |    2 -
 framework/inc/jobs/jobdata.hxx                                                 
              |    2 -
 framework/inc/threadhelp/transactionmanager.hxx                                
              |    2 -
 framework/source/accelerators/keymapping.cxx                                   
              |    2 -
 framework/source/accelerators/presethandler.cxx                                
              |    2 -
 framework/source/dispatch/closedispatcher.cxx                                  
              |    2 -
 framework/source/dispatch/dispatchprovider.cxx                                 
              |    8 ++--
 framework/source/fwe/dispatch/interaction.cxx                                  
              |    2 -
 framework/source/fwi/jobs/configaccess.cxx                                     
              |    2 -
 framework/source/fwi/threadhelp/transactionmanager.cxx                         
              |    2 -
 framework/source/helper/ocomponentenumeration.cxx                              
              |    4 +-
 framework/source/helper/oframes.cxx                                            
              |    2 -
 framework/source/inc/accelerators/presethandler.hxx                            
              |    4 +-
 framework/source/inc/loadenv/loadenv.hxx                                       
              |    2 -
 framework/source/jobs/job.cxx                                                  
              |    2 -
 framework/source/recording/dispatchrecordersupplier.cxx                        
              |    2 -
 framework/source/services/autorecovery.cxx                                     
              |   20 +++++-----
 framework/source/services/desktop.cxx                                          
              |    8 ++--
 framework/source/services/frame.cxx                                            
              |    4 +-
 helpcontent2                                                                   
              |    2 -
 include/ucbhelper/interceptedinteraction.hxx                                   
              |    2 -
 include/unotools/viewoptions.hxx                                               
              |    4 +-
 odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java         
              |    2 -
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java    
              |    4 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java  
              |    6 +--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java   
              |    2 -
 
odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
 |    2 -
 qadevOOo/tests/java/ifc/container/_XContainerQuery.java                        
              |    2 -
 sal/textenc/tcvtjp2.tab                                                        
              |    2 -
 sfx2/source/inc/templdgi.hxx                                                   
              |    2 -
 shell/source/tools/lngconvex/lngconvex.cxx                                     
              |    2 -
 toolkit/source/awt/vclxaccessiblecomponent.cxx                                 
              |    2 -
 unotools/source/config/viewoptions.cxx                                         
              |    2 -
 41 files changed, 66 insertions(+), 66 deletions(-)

New commits:
commit 037d03b9facb414ba6be01fa6ee92fc7ca89f70c
Author: Julien Nabet <serval2...@yahoo.fr>
Date:   Wed Sep 10 22:35:39 2014 +0200

    Typo: (N|n)ormaly->(N|n)ormally
    
    Change-Id: I96d081f394b0b62d99ec1034bf5e99da9aedd9d9

diff --git a/dbaccess/source/ui/browser/unodatbr.cxx 
b/dbaccess/source/ui/browser/unodatbr.cxx
index 1076acc..4e8e4e7 100644
--- a/dbaccess/source/ui/browser/unodatbr.cxx
+++ b/dbaccess/source/ui/browser/unodatbr.cxx
@@ -659,7 +659,7 @@ bool SbaTableQueryBrowser::InitializeGridModel(const 
Reference< ::com::sun::star
             Reference<XConnection> xConnection;
             Reference<XPropertySet> xRowSetProps(getRowSet(),UNO_QUERY);
             xRowSetProps->getPropertyValue( PROPERTY_ACTIVE_CONNECTION ) >>= 
xConnection;
-            OSL_ENSURE(xConnection.is(),"A ActiveConnection should normaly 
exists!");
+            OSL_ENSURE(xConnection.is(),"A ActiveConnection should normally 
exists!");
 
             Reference<XChild> xChild(xConnection,UNO_QUERY);
             Reference<XPropertySet> 
xDataSourceProp(xChild->getParent(),UNO_QUERY);
diff --git a/editeng/source/editeng/impedit3.cxx 
b/editeng/source/editeng/impedit3.cxx
index e23b4e8..09367ca 100644
--- a/editeng/source/editeng/impedit3.cxx
+++ b/editeng/source/editeng/impedit3.cxx
@@ -1533,7 +1533,7 @@ bool ImpEditEngine::CreateLines( sal_Int32 nPara, 
sal_uInt32 nStartPosY )
                 }
                 else if ( nIndex && bLineBreak && GetTextRanger() )
                 {
-                    // normaly CreateAndInsertEmptyLine would be called, but I 
want to use
+                    // normally CreateAndInsertEmptyLine would be called, but 
I want to use
                     // CreateLines, so I need Polygon code only here...
                     TextPortion* pDummyPortion = new TextPortion( 0 );
                     pParaPortion->GetTextPortions().Append(pDummyPortion);
diff --git a/filter/source/config/cache/cacheitem.hxx 
b/filter/source/config/cache/cacheitem.hxx
index 118057b..7aac754 100644
--- a/filter/source/config/cache/cacheitem.hxx
+++ b/filter/source/config/cache/cacheitem.hxx
@@ -155,7 +155,7 @@ class CacheItem : public ::comphelper::SequenceAsHashMap
         /** @short  convert this structure to a seq< PropertyValue >
                     and ignore all empty properties!
 
-            @descr  Normaly the converter routines of the base class
+            @descr  Normally the converter routines of the base class
                     SequenceAsHashMap do this job already.
                     But it doesn't provide a "pack" mechanism to
                     ignore properties with empty (means "void") values.
diff --git a/filter/source/config/cache/typedetection.hxx 
b/filter/source/config/cache/typedetection.hxx
index f65755b..82f383a 100644
--- a/filter/source/config/cache/typedetection.hxx
+++ b/filter/source/config/cache/typedetection.hxx
@@ -138,7 +138,7 @@ private:
 
         @descr      This is an optinal action to be more robust
                     in case any detect service doesn't make this seek ...
-                    Normaly it's part of any called detect service or filter 
...
+                    Normally it's part of any called detect service or filter 
...
                     but sometimes it's not done there.
 
         @param      rDescriptor
@@ -288,7 +288,7 @@ private:
     /** @short      search the best suitable filter for the given type
                     and add it into the media descriptor.
 
-        @descr      Normaly this is a type detection only ...
+        @descr      Normally this is a type detection only ...
                     but for some special features we must overwrite our 
detection
                     because a file must be loaded into a special (means 
preselected)
                     application.
diff --git a/fpicker/source/win32/misc/WinImplHelper.cxx 
b/fpicker/source/win32/misc/WinImplHelper.cxx
index da5c041..84d76d7 100644
--- a/fpicker/source/win32/misc/WinImplHelper.cxx
+++ b/fpicker/source/win32/misc/WinImplHelper.cxx
@@ -457,7 +457,7 @@ OUString SOfficeToWindowsLabel( const OUString& aSOLabel )
         // in the worst case the new string is
         // doubled in length, maybe some waste
         // of memory but how long is a label
-        // normaly(?)
+        // normally(?)
         OUStringBuffer aBuffer( nStrLen * 2 );
 
         Replace( aWinLabel, TILDE_SIGN, AMPERSAND_SIGN, aBuffer );
@@ -488,7 +488,7 @@ OUString WindowsToSOfficeLabel( const OUString& aWinLabel )
         // in the worst case the new string is
         // doubled in length, maybe some waste
         // of memory but how long is a label
-        // normaly(?)
+        // normally(?)
         OUStringBuffer aBuffer( nStrLen * 2 );
 
         Replace( aSOLabel, AMPERSAND_SIGN, TILDE_SIGN, aBuffer );
diff --git a/framework/inc/classes/filtercachedata.hxx 
b/framework/inc/classes/filtercachedata.hxx
index af9053a..9563878 100644
--- a/framework/inc/classes/filtercachedata.hxx
+++ b/framework/inc/classes/filtercachedata.hxx
@@ -279,7 +279,7 @@ struct Loader
 };
 
 // Programmer can register his own services to handle a FileType and intercept 
dispatches.
-// Don't forget: It's not a FrameLoader - it's a ContentHandler! (normaly 
without any UI)
+// Don't forget: It's not a FrameLoader - it's a ContentHandler! (normally 
without any UI)
 
 struct ContentHandler
 {
@@ -375,7 +375,7 @@ class PerformanceHash   :   public  ::boost::unordered_map< 
   OUString
             PerformanceHash().swap( *this ); // get rid of reserved capacity
         }
 
-        //  normaly a complete string must match our hash key values ...
+        //  normally a complete string must match our hash key values ...
         //  But sometimes we need a search by using these key values as 
pattern!
         //  The in/out parameter "pStepper" is used to return a pointer to 
found element in hash ...
         //  and could be used for further searches again, which should be 
started at next element!
diff --git a/framework/inc/dispatch/closedispatcher.hxx 
b/framework/inc/dispatch/closedispatcher.hxx
index db5f7c3..dfbf6bf 100644
--- a/framework/inc/dispatch/closedispatcher.hxx
+++ b/framework/inc/dispatch/closedispatcher.hxx
@@ -255,7 +255,7 @@ class CloseDispatcher : public  ::cppu::WeakImplHelper2<
                     has to be closed itself (target=_self) ... sometimes its 
parent frame
                     has to be closed - BUT(!) it means a parent frame 
containing a top level
                     window. _top can't be used then for dispatch - because it 
address TopFrames
-                    not frames containg top level windows. So normaly _magic 
(which btw does not
+                    not frames containg top level windows. So normally _magic 
(which btw does not
                     exists at the moment .-) ) should be used. So we interpret 
target=<empty>
                     as _magic !
 
diff --git a/framework/inc/dispatch/interceptionhelper.hxx 
b/framework/inc/dispatch/interceptionhelper.hxx
index c338394..e032017 100644
--- a/framework/inc/dispatch/interceptionhelper.hxx
+++ b/framework/inc/dispatch/interceptionhelper.hxx
@@ -256,7 +256,7 @@ class InterceptionHelper : public  ::cppu::WeakImplHelper3<
         /** @short      Is called from our owner frame, in case he will be 
disposed.
 
             @descr      We have to relaease all references to him then.
-                        Normaly we will die by ref count too ...
+                        Normally we will die by ref count too ...
          */
         virtual void SAL_CALL disposing(const css::lang::EventObject& aEvent)
             throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
diff --git a/framework/inc/general.h b/framework/inc/general.h
index 018eeae..bb7d81b 100644
--- a/framework/inc/general.h
+++ b/framework/inc/general.h
@@ -22,7 +22,7 @@
 
 #include <macros/generic.hxx>
 
-/* Normaly XInterface isn't used here ...
+/* Normally XInterface isn't used here ...
    But we need it to be able to define namespace alias css to anything related 
to ::com::sun::star
    :-) */
 #include <com/sun/star/uno/XInterface.hpp>
diff --git a/framework/inc/jobs/jobdata.hxx b/framework/inc/jobs/jobdata.hxx
index c7715f0..18d01e8 100644
--- a/framework/inc/jobs/jobdata.hxx
+++ b/framework/inc/jobs/jobdata.hxx
@@ -79,7 +79,7 @@ class JobData
 
         /** Some jobs can be registered to "logical events", which are 
generated on demand if another document event
             occurs. E.g. "onDocumentOpened" in case "OnNew" or "OnLoad" was 
notified to the JobExecutor instance.
-            And normaly the original event is transported as parameter set to 
the executed job. But then such job
+            And normally the original event is transported as parameter set to 
the executed job. But then such job
             can't differ between e.g. "OnNew" and "onDocumentOpened".
             That's why we must know, for which type of event the job was 
really triggered .-)
 
diff --git a/framework/inc/threadhelp/transactionmanager.hxx 
b/framework/inc/threadhelp/transactionmanager.hxx
index 8d87a51..b48ff30 100644
--- a/framework/inc/threadhelp/transactionmanager.hxx
+++ b/framework/inc/threadhelp/transactionmanager.hxx
@@ -89,7 +89,7 @@ enum ERejectReason
                                                             m_nA = nA;
                                                         }
 
-                                                Normaly (if E_HARDEXCEPTIONS 
was used!) creation of guard
+                                                Normally (if E_HARDEXCEPTIONS 
was used!) creation of guard
                                                 will throw an exception ... 
but using of E_SOFTEXCEPTIONS suppress it
                                                 and member "A" can be set.
 
*//*-*************************************************************************************************************/
diff --git a/framework/source/accelerators/keymapping.cxx 
b/framework/source/accelerators/keymapping.cxx
index c07231b..188609b 100644
--- a/framework/source/accelerators/keymapping.cxx
+++ b/framework/source/accelerators/keymapping.cxx
@@ -197,7 +197,7 @@ bool 
KeyMapping::impl_st_interpretIdentifierAsPureKeyCode(const OUString& sIdent
         return true;
     }
 
-    // 0 is normaly an error of the called method toInt32() ...
+    // 0 is normally an error of the called method toInt32() ...
     // But we must be aware, that the identifier is "0"!
     rCode = 0;
     return sIdentifier == "0";
diff --git a/framework/source/accelerators/presethandler.cxx 
b/framework/source/accelerators/presethandler.cxx
index d7548c4..0a200e3 100644
--- a/framework/source/accelerators/presethandler.cxx
+++ b/framework/source/accelerators/presethandler.cxx
@@ -445,7 +445,7 @@ void PresetHandler::connectToResource(      
PresetHandler::EConfigType
         xShare = impl_openLocalizedPathIgnoringErrors(sLocalizedSharePath, 
eShareMode, true , aShareLocale, bAllowFallbacks);
 
         // The try to locate the right sub dir inside user layer ... without 
using fallbacks!
-        // Normaly the corresponding sub dir should be created matching the 
specified locale.
+        // Normally the corresponding sub dir should be created matching the 
specified locale.
         // Because we allow creation of storages inside user layer by default.
         OUString      aUserLocale( rLanguageTag.getBcp47());
         OUString      sLocalizedUserPath(sRelPathUser);
diff --git a/framework/source/dispatch/closedispatcher.cxx 
b/framework/source/dispatch/closedispatcher.cxx
index 305e5ed..dda9c32 100644
--- a/framework/source/dispatch/closedispatcher.cxx
+++ b/framework/source/dispatch/closedispatcher.cxx
@@ -486,7 +486,7 @@ bool CloseDispatcher::implts_closeFrame()
         return true;
 
     // dont deliver owner ship; our "UI user" will try it again if it failed.
-    // OK - he will get an empty frame then. But normaly an empty frame
+    // OK - he will get an empty frame then. But normally an empty frame
     // should be closeable always :-)
     if (!fpf::closeIt(xFrame, false))
         return false;
diff --git a/framework/source/dispatch/dispatchprovider.cxx 
b/framework/source/dispatch/dispatchprovider.cxx
index 5de428a..e46d6fb 100644
--- a/framework/source/dispatch/dispatchprovider.cxx
+++ b/framework/source/dispatch/dispatchprovider.cxx
@@ -181,7 +181,7 @@ css::uno::Reference< css::frame::XDispatch > 
DispatchProvider::implts_queryDeskt
     // I.I) "_blank"
     //  It's not the right place to create a new task here - because we are 
queried for a dispatch object
     //  only, which can handle such request. Such dispatcher should create the 
required task on demand.
-    //  Normaly the functionality for "_blank" is provided by findFrame() - 
but that would create it directly
+    //  Normally the functionality for "_blank" is provided by findFrame() - 
but that would create it directly
     //  here. Thats why we must "intercept" here.
 
     if (sTargetFrameName==SPECIALTARGET_BLANK)
@@ -204,7 +204,7 @@ css::uno::Reference< css::frame::XDispatch > 
DispatchProvider::implts_queryDeskt
 
     // I.III) "_self", "", "_top"
     //  The desktop can't load any document - but he can handle some special 
protocols like "uno", "slot" ...
-    //  Why is "top" here handled too? Because the desktop is the topest 
frame. Normaly it's superflous
+    //  Why is "top" here handled too? Because the desktop is the topest 
frame. Normally it's superflous
     //  to use this target - but we can handle it in the same manner then 
"_self".
 
     else if (
@@ -258,7 +258,7 @@ css::uno::Reference< css::frame::XDispatch > 
DispatchProvider::implts_queryFrame
 
     // I.I) "_blank", "_default"
     //  It's not the right place to create a new task here. Only the desktop 
can do that.
-    //  Normaly the functionality for "_blank" is provided by findFrame() - 
but that would create it directly
+    //  Normally the functionality for "_blank" is provided by findFrame() - 
but that would create it directly
     //  here. Thats why we must "intercept" here.
 
     if (
@@ -327,7 +327,7 @@ css::uno::Reference< css::frame::XDispatch > 
DispatchProvider::implts_queryFrame
         else
         {
             css::uno::Reference< css::frame::XDispatchProvider > xParent( 
xFrame->getCreator(), css::uno::UNO_QUERY );
-            // Normaly if isTop() returned sal_False ... the parent frame 
MUST(!) exist ...
+            // Normally if isTop() returned sal_False ... the parent frame 
MUST(!) exist ...
             // But it seems to be better to check that here to prevent us 
against an access violation.
             if (xParent.is())
                 xDispatcher = xParent->queryDispatch(aURL, SPECIALTARGET_TOP, 
0);
diff --git a/framework/source/fwe/dispatch/interaction.cxx 
b/framework/source/fwe/dispatch/interaction.cxx
index 3f06725..49acb01 100644
--- a/framework/source/fwe/dispatch/interaction.cxx
+++ b/framework/source/fwe/dispatch/interaction.cxx
@@ -32,7 +32,7 @@ namespace framework{
                     code user of interaction.
 
     @attention      This implementation could be used one times only. We don't 
support a resetable continuation yet!
-                    Why? Normaly interaction should show a filter selection 
dialog and ask user for his decision.
+                    Why? Normally interaction should show a filter selection 
dialog and ask user for his decision.
                     He can select any filter - then instances of these class 
will be called by handler ... or user
                     close dialog without any selection. Then another 
continuation should be slected by handler to
                     abort continuations ... Retrying isn't very useful here 
... I think.
diff --git a/framework/source/fwi/jobs/configaccess.cxx 
b/framework/source/fwi/jobs/configaccess.cxx
index e7ba818..bacc8c1 100644
--- a/framework/source/fwi/jobs/configaccess.cxx
+++ b/framework/source/fwi/jobs/configaccess.cxx
@@ -55,7 +55,7 @@ ConfigAccess::ConfigAccess( /*IN*/ const css::uno::Reference< 
css::uno::XCompone
 /**
     @short  last chance to close an open configuration access point
     @descr  In case our user forgot to close this configuration point
-            in the right way, normaly he will run into some trouble -
+            in the right way, normally he will run into some trouble -
             e.g. losing data.
  */
 ConfigAccess::~ConfigAccess()
diff --git a/framework/source/fwi/threadhelp/transactionmanager.cxx 
b/framework/source/fwi/threadhelp/transactionmanager.cxx
index 521f168..784266a 100644
--- a/framework/source/fwi/threadhelp/transactionmanager.cxx
+++ b/framework/source/fwi/threadhelp/transactionmanager.cxx
@@ -256,7 +256,7 @@ void TransactionManager::impl_throwExceptions( 
EExceptionMode eMode, ERejectReas
                                         // Help programmer to find out, why 
this exception is thrown!
                                         SAL_WARN( "fwk", 
"TransactionManager...: Owner instance not correctly initialized yet. Call was 
rejected! Normally it's an algorithm error ... wrong use of class!" );
                                         //ATTENTION: temp. disabled - till all 
bad code positions are detected and changed! */
-                                        // throw css::uno::RuntimeException( 
"TransactionManager...\nOwner instance not right initialized yet. Call was 
rejected! Normaly it's an algorithm error ... wrong usin of class!\n", 
css::uno::Reference< css::uno::XInterface >() );
+                                        // throw css::uno::RuntimeException( 
"TransactionManager...\nOwner instance not right initialized yet. Call was 
rejected! Normally it's an algorithm error ... wrong usin of class!\n", 
css::uno::Reference< css::uno::XInterface >() );
                                     }
                                     break;
         case E_INCLOSE         :    if( eMode == E_HARDEXCEPTIONS )
diff --git a/framework/source/helper/ocomponentenumeration.cxx 
b/framework/source/helper/ocomponentenumeration.cxx
index c54a6a8..0fe7cd2 100644
--- a/framework/source/helper/ocomponentenumeration.cxx
+++ b/framework/source/helper/ocomponentenumeration.cxx
@@ -103,12 +103,12 @@ void OComponentEnumeration::impl_resetObject()
     // Attention:
     // Write this for multiple calls - NOT AT THE SAME TIME - but for more 
than one call again)!
     // It exist two ways to call this method. From destructor and from 
disposing().
-    // I can't say, which one is the first. Normaly the disposing-call - but 
other way ....
+    // I can't say, which one is the first. Normally the disposing-call - but 
other way ....
 
     // Delete list of components.
     m_seqComponents.realloc( 0 );
     // Reset position in list.
-    // The list has no elements anymore. m_nPosition is normaly the current 
position in list for nextElement!
+    // The list has no elements anymore. m_nPosition is normally the current 
position in list for nextElement!
     // But a position of 0 in a list of 0 items is an invalid state. This 
constellation can't work in future.
     // End of enumeration is arrived!
     // (see hasMoreElements() for more details...)
diff --git a/framework/source/helper/oframes.cxx 
b/framework/source/helper/oframes.cxx
index 16a8a42..e79593a 100644
--- a/framework/source/helper/oframes.cxx
+++ b/framework/source/helper/oframes.cxx
@@ -288,7 +288,7 @@ void OFrames::impl_resetObject()
     // Attention:
     // Write this for multiple calls - NOT AT THE SAME TIME - but for more 
than one call again)!
     // It exist two ways to call this method. From destructor and from 
disposing().
-    // I can't say, which one is the first. Normaly the disposing-call - but 
other way ....
+    // I can't say, which one is the first. Normally the disposing-call - but 
other way ....
 
     // This instance can't work if the weakreference to owner is invalid!
     // Destroy this to reset this object.
diff --git a/framework/source/inc/accelerators/presethandler.hxx 
b/framework/source/inc/accelerators/presethandler.hxx
index 156588b..f34be57 100644
--- a/framework/source/inc/accelerators/presethandler.hxx
+++ b/framework/source/inc/accelerators/presethandler.hxx
@@ -341,7 +341,7 @@ class PresetHandler
                     and return it.
 
             @descr  Note: Targets resist inside the user
-                    layer. Normaly they are opened in read/write mode.
+                    layer. Normally they are opened in read/write mode.
                    But it will be opened readonly automatically if that isn't 
possible
                     (may be the file is write protected on the system ...).
 
@@ -397,7 +397,7 @@ class PresetHandler
         /** @short  try to find the specified locale inside list of possible 
ones.
 
             @descr  The lits of possible locale values was e.g. retrieved from 
the system
-                    (configuration, directory listing etcpp). The locale 
normaly represent
+                    (configuration, directory listing etcpp). The locale 
normally represent
                     the current office locale. This method search for a 
suitable item by using
                     different algorithm.
                     a) exact search
diff --git a/framework/source/inc/loadenv/loadenv.hxx 
b/framework/source/inc/loadenv/loadenv.hxx
index f26ff7a..7963ac2 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -167,7 +167,7 @@ private:
 
     /** @short  it indicates, that the old document (which was located inside 
m_xBaseFrame
                 in combination with the m_sTarget value "_self") was suspended.
-                Normaly it will be replaced by the new loaded document. But in 
case
+                Normally it will be replaced by the new loaded document. But 
in case
                 loading (not handling!) failed, it must be reactivated.
                 The default value is sal_False!
      */
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index 8c38a3e..28f9e79 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -794,7 +794,7 @@ void SAL_CALL Job::notifyClosing( const 
css::lang::EventObject& ) throw(css::uno
 }
 
 /**
-    @short      shouldn't be called normaly
+    @short      shouldn't be called normally
     @descr      But it doesn't matter, who called it. We have to kill our 
internal
                 running processes hardly.
 
diff --git a/framework/source/recording/dispatchrecordersupplier.cxx 
b/framework/source/recording/dispatchrecordersupplier.cxx
index 41bebab..8489593 100644
--- a/framework/source/recording/dispatchrecordersupplier.cxx
+++ b/framework/source/recording/dispatchrecordersupplier.cxx
@@ -92,7 +92,7 @@ void SAL_CALL DispatchRecorderSupplier::setDispatchRecorder( 
const css::uno::Ref
 /**
     @short      provides access to the dispatch recorder of this supplier
     @descr      Such recorder can be used outside to record dispatches.
-                But normaly he is used internally only. Of course he must used
+                But normally he is used internally only. Of course he must used
                 from outside to get the recorded data e.g. for saving it as a
                 script.
 
diff --git a/framework/source/services/desktop.cxx 
b/framework/source/services/desktop.cxx
index 9b59140..bde7706 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -578,7 +578,7 @@ But; Don't forget - you will be the owner of returned 
object and must release it
                 It can be, that the desktop is dead - but not your 
tasksaccess-object! Then they will do nothing!
                 You can't create enumerations then.
 
-    @attention  Normaly we don't need any lock here. We don't work on internal 
member!
+    @attention  Normally we don't need any lock here. We don't work on 
internal member!
 
     @seealso    class TasksAccess
     @return     A reference to an accessobject, which can create enumerations 
of our childtasks.
@@ -963,7 +963,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL 
Desktop::findFrame( const OUS
         }
 
         // II.II) TASKS
-        //  This is a special flag. Normaly it regulate search inside tasks 
and forbid access to parent trees.
+        //  This is a special flag. Normally it regulate search inside tasks 
and forbid access to parent trees.
         //  But the desktop exists outside such task trees. They are our sub 
trees. So the desktop implement
         //  a special feature: We use it to start search on our direct 
children only. That means we supress
         //  search on ALL child frames. May that can be useful to get access 
on opened document tasks
@@ -1054,7 +1054,7 @@ void SAL_CALL Desktop::disposing()
     m_aListenerContainer.disposeAndClear( aEvent );
 
     // Clear our child task container and forget all task references hardly.
-    // Normaly all open document was already closed by our terminate() 
function before ...
+    // Normally all open document was already closed by our terminate() 
function before ...
     // New opened frames will have a problem now .-)
     m_aChildTaskContainer.clear();
 
@@ -1157,7 +1157,7 @@ void SAL_CALL Desktop::dispatchFinished( const 
css::frame::DispatchResultEvent&
 
*//*-*************************************************************************************************************/
 void SAL_CALL Desktop::disposing( const css::lang::EventObject& ) throw( 
css::uno::RuntimeException, std::exception )
 {
-    SAL_WARN( "fwk", "Desktop::disposing(): Algorithm error! Normaly desktop 
is temp. listener ... not all the time. So this method shouldn't be called." );
+    SAL_WARN( "fwk", "Desktop::disposing(): Algorithm error! Normally desktop 
is temp. listener ... not all the time. So this method shouldn't be called." );
 }
 
 
/*-************************************************************************************************************
diff --git a/framework/source/services/frame.cxx 
b/framework/source/services/frame.cxx
index 4cadd9f..621d6ff 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -2021,7 +2021,7 @@ void SAL_CALL Frame::dispose() throw( 
css::uno::RuntimeException, std::exception
     m_aTransactionManager.setWorkingMode( E_BEFORECLOSE );
 
     // Don't show any dialogs, errors or something else any more!
-    // If somewhere called dispose() whitout close() before - normaly no 
dialogs
+    // If somewhere called dispose() whitout close() before - normally no 
dialogs
     // should exist. Otherwhise it's the problem of the outside caller.
     // Note:
     //      (a) Do it after stopWindowListening(). May that force some 
active/deactive
@@ -2482,7 +2482,7 @@ void SAL_CALL Frame::windowClosing( const 
css::lang::EventObject& ) throw( css::
 
 
/*-****************************************************************************************************
     @short      react for a show event for the internal container window
-    @descr      Normaly we don't need this information really. But we can use 
it to
+    @descr      Normally we don't need this information really. But we can use 
it to
                 implement the special feature "trigger first visible task".
 
                 Algorithm: - first we have to check if we are a top (task) 
frame
diff --git a/helpcontent2 b/helpcontent2
index 70fc0dc..18f2159 160000
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 70fc0dc34e884699f250091bebe4b9e2e858063f
+Subproject commit 18f215920e94df8383c1e30f8eb0a93c3e076016
diff --git a/include/ucbhelper/interceptedinteraction.hxx 
b/include/ucbhelper/interceptedinteraction.hxx
index acf4dc5..4de6df9 100644
--- a/include/ucbhelper/interceptedinteraction.hxx
+++ b/include/ucbhelper/interceptedinteraction.hxx
@@ -144,7 +144,7 @@ class UCBHELPER_DLLPUBLIC InterceptedInteraction : public 
::cppu::WeakImplHelper
             /** none of the specified interceptions match the incoming request 
*/
             E_NOT_INTERCEPTED,
             /** the request could be intercepted - but the specified 
continuation could not be located.
-                Thats normaly an error of the programmer. May be the 
interaction request does not use
+                Thats normally an error of the programmer. May be the 
interaction request does not use
                 the right set of continuations ... or the interception list 
contains the wrong continuation. */
             E_NO_CONTINUATION_FOUND,
             /** the request could be intercepted and the specified 
continuation could be selected successfully. */
diff --git a/include/unotools/viewoptions.hxx b/include/unotools/viewoptions.hxx
index 1e565e4..7c0a8d2 100644
--- a/include/unotools/viewoptions.hxx
+++ b/include/unotools/viewoptions.hxx
@@ -163,7 +163,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtViewOptions : 
public utl::detail::Op
         
/*-****************************************************************************************************
             @short      use it to set/get the window state of your view
             @descr      These value describe position/size and some other 
states of a window.
-                        Use it with right vcl methods directly. Normaly it's 
not necessary to
+                        Use it with right vcl methods directly. Normally it's 
not necessary to
                         parse given string!
 
             @seealso    vcl methods
@@ -212,7 +212,7 @@ class UNOTOOLS_DLLPUBLIC SAL_WARN_UNUSED SvtViewOptions : 
public utl::detail::Op
 
         
/*-****************************************************************************************************
             @short      use it to set/get ONE special user data item directly
-            @descr      Normaly you can work on full user data list by using 
"Set/GetUserData()".
+            @descr      Normally you can work on full user data list by using 
"Set/GetUserData()".
                         With this function you have an access on special list 
entries directly without any
             @onerror    In the non-product version, an assertion is made. In a 
product version, errors are silently ignored.
         
*//*-*****************************************************************************************************/
diff --git 
a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java 
b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
index fd852f3..f263f0e 100644
--- a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
+++ b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
@@ -92,7 +92,7 @@ public class AsyncJob extends    WeakBase implements 
XServiceInfo, XAsyncJob
                                           com.sun.star.task.XJobListener  
xListener)
         throws com.sun.star.lang.IllegalArgumentException
     {
-        // For asynchronous jobs a valid listener reference is guaranteed 
normaly ...
+        // For asynchronous jobs a valid listener reference is guaranteed 
normally ...
         if (xListener == null)
             throw new com.sun.star.lang.IllegalArgumentException("invalid 
listener");
 
diff --git 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
index e8d5221..407cfa4 100644
--- 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
+++ 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
@@ -319,7 +319,7 @@ public class DocumentView extends    JFrame
 
 
     /**
-     * Here we can react for System.exit() normaly.
+     * Here we can react for System.exit() normally.
      * But we use it for disposing() or windowClosing() too.
      */
     public void shutdown()
@@ -348,7 +348,7 @@ public class DocumentView extends    JFrame
             FunctionHelper.closeFrame(mxFrame);
 
         // deregister this view in the global container
-        // Normaly we should die afterwards by garbage collection ...
+        // Normally we should die afterwards by garbage collection ...
         // In cease this was the last view - it force a system.exit().
         // But then we are no longer a member of the global container
         // of possible shutdown listener ... and this method should be
diff --git 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
index 49de614..2640100 100644
--- 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
+++ 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
@@ -250,7 +250,7 @@ public class FunctionHelper
             // try new version of creation first: directly using of the window
             // handle. The old implementation of the corresponding toolkit 
method
             // requires a process ID. If this id isn't the right one a null 
object
-            // is returned. But normaly nobody outside the office knows this 
id.
+            // is returned. But normally nobody outside the office knows this 
id.
             // New version of this method ignore the id parameter and creation 
will
             // work.
             // Note: You must be sure if your window handle can be really used 
by
@@ -596,7 +596,7 @@ public class FunctionHelper
         try
         {
             // Check for supported model functionality.
-            // Normaly the application documents (text, spreadsheet ...) do so
+            // Normally the application documents (text, spreadsheet ...) do so
             // but some other ones (e.g. db components) doesn't do that.
             // They can't be save then.
             com.sun.star.frame.XModel xModel = UnoRuntime.queryInterface(
@@ -653,7 +653,7 @@ public class FunctionHelper
             // First detect factory of this document.
             // Ask for the supported service name of this document.
             // If information is available it can be used to find out which
-            // filter exist for HTML export. Normaly this filter should be 
searched
+            // filter exist for HTML export. Normally this filter should be 
searched
             // inside the filter configuration but this little demo doesn't do 
so.
             // (see service com.sun.star.document.FilterFactory for further
             // information too)
diff --git 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
index 13fad3c..5dd46da 100644
--- 
a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
+++ 
b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
@@ -101,7 +101,7 @@ public class ViewContainer extends Thread
 
     /**
      * This deregister a view from this global container.
-     * Normaly it should be the last reference to the view
+     * Normally it should be the last reference to the view
      * and her finalize() method should be called.
      * If last view will be closed here - we terminate these
      * java application too. Because there is no further
diff --git 
a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
 
b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
index c4816fa..04e9b77 100644
--- 
a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
+++ 
b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
@@ -559,7 +559,7 @@ public class AsciiReplaceFilter
 
                 measure("get text from model");
 
-                // Normaly this function isn't really cancelable
+                // Normally this function isn't really cancelable
                 // But we following operation can be very expensive. So
                 // this place is the last one to stop it.
                 synchronized(this)
diff --git a/qadevOOo/tests/java/ifc/container/_XContainerQuery.java 
b/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
index 5e8748b..20e49b7 100644
--- a/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
+++ b/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
@@ -40,7 +40,7 @@ import com.sun.star.container.XEnumeration;
 *    <code>NameValue[]</code> which is a valid argument for
 *     <code>createSubSetEnumerationByProperties()</code>.</li>
 *  <li> <code>'XContainerQuery.createSubSetEnumerationByQuery'</code> : 
<b>(optional)</b>
-*     Normaly <code>createSubSetEnumerationByProperties()</code> covers all
+*     Normally <code>createSubSetEnumerationByProperties()</code> covers all
 *    possible queries. But for special cases, i.e. sorted output, the function
 *    <code>createSubSetEnumerationByQuery()</code> was made. The special cases 
was not
 *    implemented by default in the implementation object. So this function 
could be
diff --git a/sal/textenc/tcvtjp2.tab b/sal/textenc/tcvtjp2.tab
index 2957905..1910551 100644
--- a/sal/textenc/tcvtjp2.tab
+++ b/sal/textenc/tcvtjp2.tab
@@ -144,7 +144,7 @@ static sal_uInt16 const aImplUniToDBCSTab_SJIS_04[] =
 /* 0x2014 --> 0x815C - APPLE_JAPANESE/SJIS, but I think, this extension is 
better than the replacment char */
 /* 0x2015 --> 0x815C - MS932, but I think, this extension is better than the 
replacment char */
 /* 0x2016 --> 0x8161 - APPLE_JAPANESE/SJIS, but I think, this extension is 
better than the replacment char */
-/* 0x2026 --> 0x8163 - APPLE_JAPANESE is normaly 0x00FF (HORIZONTAL ELLIPSIS), 
because in the APPLE import table 0x8183 is this 0x22EF (MIDLINE HORIZONTAL 
ELLIPSIS) */
+/* 0x2026 --> 0x8163 - APPLE_JAPANESE is normally 0x00FF (HORIZONTAL 
ELLIPSIS), because in the APPLE import table 0x8183 is this 0x22EF (MIDLINE 
HORIZONTAL ELLIPSIS) */
 /*                     but we import this code as 0x2026 */
 /* 0x203E --> 0x8150 - APPLE_JAPANESE, but I think, this extension is better 
than the replacment char */
 /*                     in SJIS this is 0x7E, but we import 0x7E as 0x7E, so 
this would be the better way */
diff --git a/sfx2/source/inc/templdgi.hxx b/sfx2/source/inc/templdgi.hxx
index 2988d0a..2cbe1b7 100644
--- a/sfx2/source/inc/templdgi.hxx
+++ b/sfx2/source/inc/templdgi.hxx
@@ -291,7 +291,7 @@ public:
     inline bool         CanHide( void ) const    { return bCanHide; }
     inline bool         CanShow( void ) const    { return bCanShow; }
 
-    // normaly for derivates from SvTreeListBoxes, but in this case the dialog 
handles context menus
+    // normally for derivates from SvTreeListBoxes, but in this case the 
dialog handles context menus
     virtual PopupMenu*  CreateContextMenu( void );
 };
 
diff --git a/shell/source/tools/lngconvex/lngconvex.cxx 
b/shell/source/tools/lngconvex/lngconvex.cxx
index 22c0bc1..bb08e4d 100644
--- a/shell/source/tools/lngconvex/lngconvex.cxx
+++ b/shell/source/tools/lngconvex/lngconvex.cxx
@@ -431,7 +431,7 @@ void start_language_section(
     char buff[10];
     int primLangID = PRIMARYLANGID(ltype);
     int subLangID = SUBLANGID(ltype);
-    // Our resources are normaly not sub language dependent.
+    // Our resources are normally not sub language dependent.
     // Esp. for spanish we don't want to distinguish between trad.
     // and internatinal sorting ( which leads to two different sub languages )
     // Setting the sub language to neutral allows us to use one
diff --git a/toolkit/source/awt/vclxaccessiblecomponent.cxx 
b/toolkit/source/awt/vclxaccessiblecomponent.cxx
index 0292857..ab92152 100644
--- a/toolkit/source/awt/vclxaccessiblecomponent.cxx
+++ b/toolkit/source/awt/vclxaccessiblecomponent.cxx
@@ -143,7 +143,7 @@ uno::Reference< accessibility::XAccessible > 
VCLXAccessibleComponent::GetChildAc
     // checks if the data in the window event is our direct child
     // and returns its accessible
 
-    // MT: Change this later, normaly a show/hide event shouldn't have the 
Window* in pData.
+    // MT: Change this later, normally a show/hide event shouldn't have the 
Window* in pData.
     Window* pChildWindow = (Window *) rVclWindowEvent.GetData();
     if( pChildWindow && GetWindow() == 
pChildWindow->GetAccessibleParentWindow() )
         return pChildWindow->GetAccessible( rVclWindowEvent.GetId() == 
VCLEVENT_WINDOW_SHOW );
diff --git a/unotools/source/config/viewoptions.cxx 
b/unotools/source/config/viewoptions.cxx
index 22f2053..732d170 100644
--- a/unotools/source/config/viewoptions.cxx
+++ b/unotools/source/config/viewoptions.cxx
@@ -136,7 +136,7 @@ class SvtViewOptionsBase_Impl
     @short          ctor
     @descr          We use it to open right configuration file and let 
configuration objects fill her caches.
                     Then we read all existing entries from right list and 
cached it inside our object too.
-                    Normaly we should enable notifications for changes on 
these values too ... but these feature
+                    Normally we should enable notifications for changes on 
these values too ... but these feature
                     isn't full implemented in the moment.
 
     @seealso        baseclass ::utl::ConfigItem
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/framework/source/services/autorecovery.cxx 
b/framework/source/services/autorecovery.cxx
index ac68885..8efe331 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -128,7 +128,7 @@ public:
     /** @short  can be set from outside and is provided to
                 our internal started operations.
 
-        @descr  Normaly we use the normal status indicator
+        @descr  Normally we use the normal status indicator
                 of the document windows to show a progress.
                 But in case we are used by any special UI,
                 it can provide its own status indicator object
@@ -1739,7 +1739,7 @@ void SAL_CALL AutoRecovery::disposing(const 
css::lang::EventObject& aEvent)
     }
 
     // dispose from one of our cached documents ?
     // Normaly they should send a OnUnload message ...
     // But some stacktraces shows another possible use case .-)
     css::uno::Reference< css::frame::XModel > xDocument(aEvent.Source, 
css::uno::UNO_QUERY);
     if (xDocument.is())
@@ -2341,7 +2341,7 @@ IMPL_LINK_NOARG(AutoRecovery, implts_timerExpired)
 
         // The timer must be ignored if AutoSave/Recovery was disabled for this
         // office session. That can happen if e.g. the command line arguments 
"--norestore" or "--headless"
-        // was set. But normaly the timer was disabled if recovery was 
disabled ...
+        // was set. But normally the timer was disabled if recovery was 
disabled ...
         // But so we are more "safe" .-)
         /* SAFE */ {
         osl::MutexGuard g(cppu::WeakComponentImplHelperBase::rBHelper.rMutex);
@@ -2458,7 +2458,7 @@ void AutoRecovery::implts_registerDocument(const 
css::uno::Reference< css::frame
     AutoRecovery::TDocumentList::iterator pIt = 
AutoRecovery::impl_searchDocument(m_lDocCache, xDocument);
     if (pIt != m_lDocCache.end())
     {
         // Normaly nothing must be done for this "late" notification.
         // But may be the modified state was changed inbetween.
         // Check it ...
         implts_updateModifiedState(xDocument);
@@ -2871,7 +2871,7 @@ void AutoRecovery::implts_prepareSessionShutdown()
 
         #i64599#
 
-        Normaly the MediaDescriptor argument NoAutoSave indicates,
+        Normally the MediaDescriptor argument NoAutoSave indicates,
         that a document must be ignored for AutoSave and Recovery.
         But sometimes XModel->getArgs() does not contained this information
         if implts_registerDocument() was called.
@@ -2976,7 +2976,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_saveDocs(   
    bool        bAllow
         //      save it after all other documents was saved successfully. That 
decrease
         //      the chance for a crash inside a crash.
         //      On the other side it's not necessary for documents, which are 
not modified.
-        //      They can be handled normaly - means we patch the corresponding 
configuration entry only.
+        //      They can be handled normally - means we patch the 
corresponding configuration entry only.
         // iii) For a SessionSave ... ignore it! There is no time to wait for 
this save operation.
         //      Because the WindowManager will kill the process if it doesn't 
react immediately.
         //      On the other side we can't risk a concurrent save request ... 
because we know
@@ -3383,7 +3383,7 @@ AutoRecovery::ETimerType 
AutoRecovery::implts_openDocs(const DispatchParams& aPa
         implts_informListener(eJob,
             AutoRecovery::implst_createFeatureStateEvent(eJob, 
OPERATION_UPDATE, &rInfo));
 
-        /* Normaly we listen as XModifyListener on a document to know if a 
document was changed
+        /* Normally we listen as XModifyListener on a document to know if a 
document was changed
            since our last AutoSave. And we deregister us in case we know this 
state.
            But directly after one document as recovered ... we must start 
listening.
            Otherwhise the first "modify" doesn't reach us. Because we ourself 
called setModified()
@@ -3730,7 +3730,7 @@ void AutoRecovery::implts_doEmergencySave(const 
DispatchParams& aParams)
     // The called method for saving documents runs
     // during normal AutoSave more than once. Because
     // it postpone active documents and save it later.
     // That is normaly done by recalling it from a timer.
     // Here we must do it immediately!
     // Of course this method returns the right state -
     // because it knows, that we are running in ERMERGENCY SAVE mode .-)
@@ -3798,7 +3798,7 @@ void AutoRecovery::implts_doSessionSave(const 
DispatchParams& aParams)
     // The called method for saving documents runs
     // during normal AutoSave more than once. Because
     // it postpone active documents and save it later.
     // That is normaly done by recalling it from a timer.
     // Here we must do it immediately!
     // Of course this method returns the right state -
     // because it knows, that we are running in SESSION SAVE mode .-)
@@ -4239,7 +4239,7 @@ void AutoRecovery::impl_establishProgress(const 
AutoRecovery::TDocumentInfo&
                                                                                
 utl::MediaDescriptor::PROP_STATUSINDICATOR(),
                                                                                
 css::uno::Reference< css::task::XStatusIndicator >() );
 
-    // Normaly a progress is set from outside (e.g. by the CrashSave/Recovery 
dialog, which uses our dispatch API).
+    // Normally a progress is set from outside (e.g. by the CrashSave/Recovery 
dialog, which uses our dispatch API).
     // But for a normal auto save we dont have such "external progress"... 
@@ -1739,7 +1739,7 @@ void SAL_CALL AutoRecovery::disposing(const 
 
     // dispose from one of our cached documents ?
-    // Normaly they should send a OnUnload message ...
+    // Normally they should send a OnUnload message ...
     // But some stacktraces shows another possible use case .-)
     css::uno::Reference< css::frame::XModel > xDocument(aEvent.Source, 
@@ -2458,7 +2458,7 @@ void AutoRecovery::implts_registerDocument(const 
     if (pIt != m_lDocCache.end())
     {
-        // Normaly nothing must be done for this "late" notification.
+        // Normally nothing must be done for this "late" notification.
         // But may be the modified state was changed inbetween.
         // Check it ...
@@ -3730,7 +3730,7 @@ void AutoRecovery::implts_doEmergencySave(const 
     // during normal AutoSave more than once. Because
     // it postpone active documents and save it later.
-    // That is normaly done by recalling it from a timer.
+    // That is normally done by recalling it from a timer.
     // Here we must do it immediately!
     // Of course this method returns the right state -
@@ -3798,7 +3798,7 @@ void AutoRecovery::implts_doSessionSave(const 
     // during normal AutoSave more than once. Because
     // it postpone active documents and save it later.
-    // That is normaly done by recalling it from a timer.
+    // That is normally done by recalling it from a timer.
     // Here we must do it immediately!
     // Of course this method returns the right state -
because this function is triggered by our own timer then.
     // In such case we must create our own progress !
     if (